import React from "react";
// library to set properties for components
import PropTypes from "prop-types";
import { isEmpty, isObject, isArray } from "lodash";
import styled from "styled-components";
// custom select component for react
import Select from "react-select";
// core components
// styles
import { dropDownStyles } from "./styles";
import colors from "./color";

const StyledSelect = styled(Select)`
  && {
    font-size: ${(props) => `${props.fontSize} !important`};
    color: ${(props) => `${props.color} !important`};
    border-color: ${(props) => `${props.borderColor} !important`};
    background-color: ${(props) => `${props.bgColor} !important`};
  }
  && div[class*="singleValue"] {
    color: ${(props) => `${props.color} !important`};
  }
  && div[class*="control"] {
   &:hover {
        border-color:  ${(props) =>
          props.theme === "light" && "#767676 !important"}
      },
  }
  && div[class*="MenuList"] {
    background-color: ${(props) => `${props.bgColor} !important`};
  }
  && div[class*="option"] {
    color: ${(props) => `${props.color} !important`};
    background-color: ${(props) => `${props.bgColor} !important`};
  }
`;
const customStyles = (isButton, width, theme) => ({
  control: (provided, state) => {
    return {
      ...provided,
      minWidth: 140,
      width,
      background: !isButton
        ? "transparent"
        : theme === "light"
        ? "#fff"
        : colors.dark.dark15,
      borderColor: !isButton
        ? theme === "light"
          ? state.isFocused
            ? "#767676"
            : "#c7c7c7"
          : colors.dark.dark15
        : "transparent !important",
      boxShadow: !isButton ? "inherit" : "none !important",
    };
  },
  menuList: (provided) => ({
    ...provided,
    minWidth: 150,
    width,
    background: theme === "light" ? "#f5f5f5" : colors.dark.buttonDark,
    color: theme === "light" ? "#767676" : colors.dark.light25,
    scrollbarWidth: "5px !important",
  }),
  menu: (provided) => ({
    ...provided,
    minWidth: 150,
    width,
    zIndex: 11,
  }),
  input: (provided) => ({
    ...provided,
    color: theme === "light" ? "#767676" : colors.dark.light25,
  }),
  dropdownIndicator: (provided) => ({
    ...provided,
    color: theme === "light" ? "#767676" : colors.dark.light25,
  }),
  indicatorSeparator: (provided) => ({
    ...provided,
    backgroundColor: !isButton
      ? "transparent"
      : theme === "light"
      ? "#767676"
      : "#e6e6e836",
    margin: !isButton ? "8px" : "5px",
  }),
  groupHeading: (provided) => ({
    ...provided,
    color: theme === "light" ? "#767676" : "#fff",
    fontWeight: "bold",
  }),
  // option: (provided, state) => {
  //   // console.log("ss", state);

  //   return {
  //     ...provided,
  //     fontWeight:
  //       theme === "light" ? (state.isSelected ? "bold" : "normal") : "normal",
  //     backgroundColor:
  //       theme === "light"
  //         ? state.isFocused
  //           ? "#fff"
  //           : "#f5f5f5"
  //         : state.isFocused
  //         ? "rgb(85, 85, 107)"
  //         : colors.dark.buttonDark,
  //     color:
  //       theme === "light" ? (state.isFocused ? "#000" : "#767676") : "inherit",
  //   };
  // },
  option: (provided, state) => ({
    ...provided,
    fontWeight:
      theme === "light" ? (state.isSelected ? "bold" : "normal") : "normal",
    backgroundColor:
      theme === "light"
        ? state.isFocused
          ? "#ffffff"
          : "#f5f5f5"
        : state.isFocused
        ? "rgb(85, 85, 107)"
        : colors.dark.buttonDark,
    color:
      theme === "light"
        ? state.isFocused
          ? "#000"
          : state.isSelected
          ? "#000"
          : "#767676"
        : state.isFocused
        ? "#fff"
        : state.isSelected
        ? "#fff"
        : "inherit",
  }),
  singleValue: (provided, state) => {
    return {
      ...provided,
      color: theme === "light" ? "#767676" : colors.dark.light24,
    };
  },
  multiValue: (provided) => ({
    ...provided,
    color: theme === "light" ? "#767676" : colors.dark.light24,
    backgroundColor: theme === "light" ? "#f5f5f5" : colors.dark.buttonDark,
  }),
  multiValueLabel: (provided) => ({
    ...provided,
    color: theme === "light" ? "#767676" : colors.dark.light24,
  }),
});
// const dropdownMenu = {
//   zIndex: "999",
//   color: "#767676 !important",
//   // backgroundColor:
//   //   theme.palette.type === 'light' ? '#f5f5f5 !important' : 'inherit',
//   '& div[class*="singleValue"]': {
//     color: "#767676 !important",
//   },
//   '& div[class*="control"]': {
//     borderColor: "#c7c7c7 !important",
//     "&:hover": {
//       borderColor: "#767676 !important",
//     },
//     // backgroundColor: theme.palette.type === 'light' && '#f5f5f5 !important'
//     backgroundColor: "white !important",
//     "& input": {
//       color: "#767676 !important",
//     },
//   },
//   '& div[class*="indicatorContainer"]': {
//     color: "hsl(0,0%,60%) !important",
//   },
//   '& div[class*="menu"] > div': {
//     backgroundColor: "#f5f5f5 !important",
//   },
//   '& div[class*="option"]': {
//     backgroundColor: "#f5f5f5 !important",
//     color: "#767676 !important",
//   },
//   '& div[class*="option"]:hover': {
//     backgroundColor: "#ffffff !important",
//     color: "#767676 !important",
//   },
// };
const Dropdown = ({
  options,
  button: isButton,
  handleValueChange,
  value: currentValue,
  width,
  title,
  isMulti,
  titleColor,
  classes,
  useMenuPortalTarget,
  routeID,
  type,
  placeholder,
  dropdownTitleStyles,
  dropdownStyles,
  isDisabled,
  dashboardType,
  theme,
}) => (
  <div style={{ margin: "10px 0px" }}>
    <span style={{ color: theme === "light" && "#3f3f3f" }}>
      {title ? title : null}
    </span>
    <StyledSelect
      theme={theme}
      color={dropdownStyles?.textColor}
      bgColor={dropdownStyles?.backgroundColor}
      fontSize={dropdownStyles?.fontSize}
      borderColor={dropdownStyles?.borderColor}
      //   className={classes.dropdownMenu}
      // styles={dropdownMenu}
      id={`${routeID}-${type}`}
      isMulti={isMulti}
      isDisabled={isDisabled}
      styles={customStyles(isButton, width, theme, dashboardType)}
      menuPortalTarget={useMenuPortalTarget && document.querySelector("body")}
      placeholder={placeholder}
      dashboardType={dashboardType}
      onChange={(updatedValue) => {
        if (isMulti) {
          let refinedValue = updatedValue ? [...updatedValue] : [];
          if (updatedValue !== null) {
            if (updatedValue.length > 1) {
              let isAllInCurrentValue = 0;
              let isAllInUpdatedValue = 0;
              if (isObject(currentValue)) {
                isAllInCurrentValue = currentValue.value === "all";
              }
              if (isArray(currentValue)) {
                isAllInCurrentValue =
                  currentValue.filter((el) => el.value === "all").length > 0;
              }
              if (isObject(updatedValue)) {
                isAllInUpdatedValue = updatedValue.value === "all";
              }
              if (isArray(updatedValue)) {
                isAllInUpdatedValue =
                  updatedValue.filter((el) => el.value === "all").length > 0;
              }
              if (isAllInCurrentValue && isAllInUpdatedValue) {
                const index = refinedValue.findIndex(
                  (el) => el.value === "all"
                );
                if (index > -1) {
                  refinedValue.splice(index, 1);
                }
              }
              if (!isAllInCurrentValue && isAllInUpdatedValue) {
                [refinedValue] = refinedValue.filter(
                  (el) => el.value === "all"
                );
              }
            }
          }
          handleValueChange(refinedValue);
        } else if (
          updatedValue.value !== currentValue.value ||
          updatedValue.value === "custom"
        ) {
          handleValueChange(updatedValue);
        }
      }}
      value={isEmpty(currentValue) ? null : currentValue}
      options={options}
    />
  </div>
);

export default Dropdown;
