import React from "react";
import Draggable from "react-draggable";
import close from "assets/close.svg";
import close_white from "assets/close_white.svg";

// for rendering image component
function isValidURL(string) {
  if (typeof string === "string") {
    //   check if the value is string
    var res = string.match(
      /(http(s)?:\/\/.)?(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#?&//=]*)/g
    );
    return res !== null;
  } else {
    return false;
  }
}

const DetailsTooltip = ({
  top = 100,
  right = 20,
  cropDetails,
  setCropDetails,
  isTse,
  theme,
}) => {
  return (
    cropDetails.show && (
      <Draggable>
        <div
          className="cropDetailsTooltip"
          style={{
            top,
            right,
            backgroundColor: theme === "light" ? "#fff" : "#2e2e31",
            color: theme === "light" ? "#767676" : "rgba(255, 255, 255, 0.6)",
          }}
        >
          {!isTse && (
            <div className="toolTipHeader">
              <button
                onClick={() => setCropDetails({ show: false, details: null })}
              >
                <img
                  src={theme === "light" ? close_white : close}
                  height="20px"
                ></img>
              </button>
            </div>
          )}
          {cropDetails.type === "boundingBox" && (
            <>
              {" "}
              <div className="cropDetailsRow">
                <div className="toolTipKeyHeader">CropId: </div>
                <div className="toolTipKeyValue">
                  {cropDetails.details.cropId}
                </div>
              </div>
              <div className="cropDetailsRow">
                <a href={cropDetails.details.imageUrl.path} target="_blank">
                  Image URL
                </a>
              </div>
            </>
          )}

          {cropDetails.details.details.map((row) =>
            Object.keys(row).map(
              (key, index) =>
                key &&
                key !== "color" && (
                  <div className="cropDetailsRow" key={index}>
                    <div className="toolTipKeyHeader">{key}: </div>
                    <div className="toolTipKeyValue">
                      {row[key] ? (
                        isValidURL(row[key]) ? (
                          <img src={row[key]} width="50%"></img>
                        ) : (
                          row[key]
                        )
                      ) : (
                        "NA"
                      )}
                    </div>
                  </div>
                )
            )
          )}
        </div>
      </Draggable>
    )
  );
};

export default DetailsTooltip;
