import React from "react";
import { ShelfDisplayConstants } from "utils/constants";

const SvgRect = React.memo(
  ({
    minimap,
    boundingBoxes,
    selectedBoxes,
    onClickBoundingBox,
    img,
    onClickPolygon,
    dynamicCheckboxes,
    viewInfo,
    isTse,
    forUpdationBoxes,
  }) => {
    const { minimapImageHeight, shelfImageHeight } = ShelfDisplayConstants;
    let factor = !minimap
      ? shelfImageHeight / img.height
      : minimapImageHeight / img.height;

    return (
      <svg id="layer" className="svgComponent rectComponent">
        {dynamicCheckboxes?.posm &&
          img.displays?.map((posm, index) => (
            <>
              <polygon
                key={index}
                height={"100%"}
                strokeWidth={minimap ? "2px" : "4px"}
                points={posm.coords
                  .split(",")
                  .map((el) => el * factor)
                  .join(",")}
                fill="transparent"
                stroke="#48ec09"
                onClick={() => onClickPolygon(posm, img)}
                style={{ zIndex: "4" }}
              />
            </>
          ))}
        {Object.keys(boundingBoxes).length &&
          boundingBoxes[img.id] &&
          boundingBoxes[img.id].map((el, index) => {
            const isBoxForUpdation = forUpdationBoxes.find(
              (box) => box.id === el.id
            );
            const isBoxSelected = selectedBoxes.find((box) => box.id === el.id);
            return (
              <rect
                key={index}
                x={el.left * factor}
                y={el.top * factor}
                width={(el.right - el.left) * factor}
                height={(el.bottom - el.top) * factor}
                stroke={
                  !dynamicCheckboxes.segment
                    ? isTse
                      ? isBoxForUpdation
                        ? "#fff"
                        : isBoxSelected
                        ? isBoxSelected.inclusion
                          ? "#48ec09"
                          : "red"
                        : el.color || "#48ec09"
                      : isBoxSelected
                      ? "#fff"
                      : el.color || "#48ec09"
                    : el.segment
                }
                strokeWidth={
                  !minimap
                    ? isBoxForUpdation || isBoxSelected
                      ? "3px"
                      : "2px"
                    : "1px"
                }
                onClick={
                  !minimap ? () => onClickBoundingBox(el, false) : undefined
                }
                onMouseOver={
                  !minimap && isTse && viewInfo
                    ? () => onClickBoundingBox(el, true)
                    : undefined
                }
                fill="transparent"
                style={{ zIndex: "3" }}
                // check if box is in forUpdation state
                strokeDasharray={isBoxForUpdation && viewInfo ? "3 3" : ""}
              />
            );
          })}
      </svg>
    );
  }
);

export default SvgRect;
