import React, { useRef, useEffect } from "react";
import ImageRenderer from "commonComponents/imageRenderer";
import { TransformWrapper, TransformComponent } from "react-zoom-pan-pinch";
import SvgRenderer from "./svgs";
import { ShelfDisplayConstants } from "utils/constants";
import ImageCaption from "commonComponents/imageCaption";
import ShelfHeader from "../ShelfHeader";
const { shelfImageHeight } = ShelfDisplayConstants;

const ImageDisplay = React.memo(
  ({
    images,
    allBoxes,
    boundingBoxes,
    selectedBoxes,
    setSelectedBoxes,
    onClickBoundingBox,
    zoom,
    setScrollValue,
    scrolLeft,
    setShowAnchor,
    setMinimapDraggableWidth,
    shelfWidth,
    setImagesSetWidth,
    onClickPolygon,
    enableZoom,
    dynamicCheckboxes,
    inclusion,
    toolbarState,
    isTse,
    forUpdationBoxes,
    theme,
  }) => {
    const divRef = useRef();

    useEffect(() => {
      divRef.current.scrollLeft = scrolLeft;
    }, [scrolLeft]);
    useEffect(() => {
      const minimapWidth = images.reduce(
        (acc, img) => acc + (shelfImageHeight * img.width) / img.height,
        0
      );
      setMinimapDraggableWidth(minimapWidth);
      setShowAnchor(
        images.reduce(
          (acc, img) => acc + (shelfImageHeight * img.width) / img.height,
          0
        ) > shelfWidth
      );
      let wi = 0;
      let widthObj = {};
      images.map((img) => {
        widthObj = { ...widthObj, ...{ [img.id]: wi } };
        wi = wi + (shelfImageHeight * img.width) / img.height;
      });
      setImagesSetWidth(widthObj);
    }, [images]);

    return (
      <TransformWrapper
        initialScale={1}
        disabled={!zoom}
        doubleClick={{ disabled: true }}
      >
        {({ zoomIn, zoomOut, resetTransform, ...rest }) => (
          <>
            <ShelfHeader
              theme={theme}
              enableZoom={enableZoom}
              isZoomEnabled={zoom}
              resetTransform={resetTransform}
            />
            <TransformComponent>
              {images && (
                <div
                  className="canvasWrapper"
                  style={{
                    height: shelfImageHeight + 50,
                    width: shelfWidth,
                    scrollbarWidth: "none",
                  }}
                  data-testid="imageDisplay-container"
                  onScroll={(e) => {
                    const target = e.target;
                    setScrollValue(target.scrollLeft);
                  }}
                  ref={divRef}
                >
                  {images.map((img, index) => (
                    <div
                      key={index}
                      className="shelfImagesWrapper"
                      data-testid="image-section"
                    >
                      <div
                        style={{
                          height: shelfImageHeight,
                          width: (shelfImageHeight * img.width) / img.height,
                        }}
                      >
                        <SvgRenderer
                          allBoxes={allBoxes}
                          boundingBoxes={boundingBoxes}
                          selectedBoxes={selectedBoxes}
                          setSelectedBoxes={setSelectedBoxes}
                          img={img}
                          onClickBoundingBox={onClickBoundingBox}
                          dynamicCheckboxes={dynamicCheckboxes}
                          onClickPolygon={onClickPolygon}
                          inclusion={toolbarState["inclusion"]}
                          viewInfo={toolbarState["viewInfo"]}
                          isTse={isTse}
                          forUpdationBoxes={forUpdationBoxes}
                        />

                        <ImageRenderer img={img.scaled_img || img.path} />
                      </div>

                      <ImageCaption img={img} />
                    </div>
                  ))}
                </div>
              )}
            </TransformComponent>
          </>
        )}
      </TransformWrapper>
    );
  }
);

export default ImageDisplay;
