import "ag-grid-community/dist/styles/ag-theme-alpine.css";
import "ag-grid-community/dist/styles/ag-theme-alpine-dark.css";
// import "ag-grid-community/dist/styles/ag-theme-material.css";
// import "ag-grid-community/dist/styles/ag-theme-dark.css";

import "ag-grid-community/dist/styles/ag-grid.css";

import React, { useEffect, useState, useCallback } from "react";
import { AgGridReact, AgGridColumn } from "ag-grid-react";

// import Checkbox from "rc-checkbox";
import styled from "styled-components";
import Checkbox from "react-custom-checkbox";
import tick from "assets/tick.svg";
import tick_white from "assets/tick_white.svg";
import ColorWheel from "commonComponents/colorWheel";
import Tabs from "commonComponents/Tabs";

const CheckboxRenderer = React.memo(
  ({ onRowSelect, data, selectedVariants, theme }) => {
    return (
      <Checkbox
        checked={selectedVariants.includes(data.id)}
        onChange={() => onRowSelect(data)}
        borderRadius={2}
        size={18}
        borderColor={
          selectedVariants.includes(data.id)
            ? theme === "light"
              ? "#0f0d36"
              : "#f50057"
            : theme === "light"
            ? "#0f0d36"
            : "rgba(255, 255, 255, 0.7)"
        }
        icon={
          <div
            style={{
              height: "100%",
              width: "100%",
              backgroundColor: theme === "light" ? "#0f0d36" : "#f50057",
              display: "flex",
              alignItems: "center",
              justifyContent: "center",
            }}
          >
            <img src={theme === "light" ? tick_white : tick} height="80%"></img>
          </div>
        }
      />
    );
  }
);

const ImageRenderer = React.memo((props) => {
  const { value, onClickImage } = props;
  if (!value) return <div>N/A</div>;
  return (
    <img onClick={() => onClickImage(props.value)} src={value} height="90%" />
  );
});

const TextRenderer = React.memo(({ value }) => {
  if (!value) return <div>N/A</div>;
  return <div>{value}</div>;
});

const CheckboxHeader = ({
  visibleBoxes,
  allVariantsSelected,
  toggleAllBoxes,
  theme,
}) => {
  return (
    <Checkbox
      checked={visibleBoxes && allVariantsSelected}
      onChange={toggleAllBoxes}
      borderRadius={2}
      size={18}
      borderColor={
        visibleBoxes && allVariantsSelected
          ? theme === "light"
            ? "#0f0d36"
            : "#f50057"
          : theme === "light"
          ? "#0f0d36"
          : "rgba(255, 255, 255, 0.7)"
      }
      icon={
        <div
          style={{
            height: "100%",
            width: "100%",
            backgroundColor: theme === "light" ? "#0f0d36" : "#f50057",
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
          }}
        >
          <img src={theme === "light" ? tick_white : tick} height="80%"></img>
        </div>
      }
    />
  );
};
const StyledTable = styled(AgGridReact)`
  && .ag-header-container {
    background: ${(props) => `${props.theme === "light" ? "#fff" : "#26293c"}`};
    border: none;
    height: 80px !important;
  }

  && .ag-header {
    border: none !important;
    height: fit-content !important;
  }
  && .ag-row {
    border: none;
    color: ${(props) =>
      `${props.theme === "light" ? "#424242" : "hsla(0, 0%, 100%, 0.6)"}`};
    font-family: "Helvetica Neue", sans-serif;
  }
  && .ag-row:nth-child(odd) {
    background: ${(props) => `${props.theme === "light" ? "#fff" : "#27293d"}`};
  }
  && .ag-row:nth-child(even) {
    background: ${(props) =>
      `${props.theme === "light" ? "#f7f7f7" : "#1e1e2b"}`};
  }
  && .ag-header-cell {
    height: 80px !important;
  }
  && .ag-header-cell-text {
    text-transform: uppercase;
    white-space: pre-wrap;
    font-size: 14px;
    color: ${(props) =>
      `${props.theme === "light" ? "#424242" : "hsla(0, 0%, 100%, 0.4)"}`};
  }
  && .ag-pinned-left-header {
    background: ${(props) => `${props.theme === "light" ? "#fff" : "#27293d"}`};
  }
  && .ag-cell {
    border: none !important;
  }
  && .ag-pinned-left-header {
    border: none !important;
  }
  && .ag-root-wrapper {
    border: none !important;
    border-radius: 0 0 calc(0.25rem - 1px) calc(0.25rem - 1px);
  }
  && .ag-center-cols-viewport {
    scrollbar-width: none !important;
  }
  && .ag-root-wrapper {
    background-color: ${(props) =>
      `${props.theme === "light" ? "#fff !important" : "#27293d !important"}`};
  }
`;

const cellRenderer = {
  imageRenderer: ImageRenderer,
  textRenderer: TextRenderer,
  checkboxRenderer: CheckboxRenderer,
};

const Table = React.memo(
  ({
    width,
    rowData,
    columnDefs,
    onRowSelect,
    visibleBoxes,
    selectedVariants,
    toggleAllBoxes,
    allVariantsSelected,
    store_explorer_settings,
    showPosm,
    dynamicCheckboxes,
    handleCheckBoxClicked,
    showCropDetails,
    imageBoundingBoxes,
    colorLegend,
    tabs,
    onTabChange,
    activeTab,
    theme,
  }) => {
    const [columns, setColumns] = useState([]);
    const [columnApi, setColumnApi] = useState(null);
    const [gridApi, setGridApi] = useState(undefined);

    useEffect(() => {
      setColumns([
        {
          field: "value",
          cellRenderer: "checkboxRenderer",
          cellStyle: function () {
            return { alignItems: "center", display: "flex" };
          },
          // on row select is not getting the updated value from the state - in away we need to find a way to add the showToolTip details to
          // the dependency list
          cellRendererParams: {
            onRowSelect,
            visibleBoxes,
            selectedVariants,
            theme,
          },
          headerComponent: CheckboxHeader,
          headerComponentParams: {
            visibleBoxes,
            allVariantsSelected,
            selectedVariants,
            toggleAllBoxes,
            theme,
          },
          pinned: "left",
        },
        ...(columnDefs || []),
      ]);
    }, [
      columnDefs,
      onRowSelect,
      visibleBoxes,
      selectedVariants,
      toggleAllBoxes,
      allVariantsSelected,
      store_explorer_settings,
      showPosm,
      dynamicCheckboxes,
      handleCheckBoxClicked,
      showCropDetails,
      imageBoundingBoxes,
      colorLegend,
    ]);

    const onGridReady = (params) => {
      setColumnApi(params.columnApi);
      setGridApi(params.api);
      window.gridApi = params.api;
      window.columnApi = params.columnApi;

      const allColumnIds = [];

      params.columnApi.getAllColumns().forEach((column, index) => {
        allColumnIds.push(column.getId());
      });
      params.columnApi.autoSizeColumns(allColumnIds, false);
      const tableWidth = params.columnApi
        .getAllColumns()
        .reduce((accu, column) => {
          accu += column.actualWidth;
          return accu;
        }, 0);

      const totalColumns = params.columnApi.getAllColumns().length - 1;
      const extraWidthForEachColumn =
        width > tableWidth ? (width - tableWidth) / totalColumns : 0;

      params.columnApi.getAllColumns().forEach((column, index) => {
        if (index > 0) {
          params.columnApi.setColumnWidth(
            column,
            column.actualWidth + extraWidthForEachColumn
          );
        }
      });
    };

    const getRowHeight = useCallback(() => {
      return 80;
    }, []);

    return (
      <div
        style={{
          color: theme === "light" ? "rgba(0, 0, 0, 0.87)" : "#ffffff99",

          backgroundColor:
            theme !== "light" ? "rgb(30, 30, 43)" : "rgb(245, 245, 245)",
        }}
      >
        <div className="tableHeaderBanner">
          <div style={{ display: "flex" }}>
            {Object.keys(store_explorer_settings).map((key) => {
              if (
                store_explorer_settings[key].enable &&
                key !== "display_caption"
              ) {
                return (
                  <div style={{ marginRight: "5px" }}>
                    {dynamicCheckboxes &&
                      Object.keys(dynamicCheckboxes).length && (
                        <Checkbox
                          checked={dynamicCheckboxes[key]}
                          onChange={() =>
                            handleCheckBoxClicked(
                              key,
                              store_explorer_settings[key]
                            )
                          }
                          borderRadius={2}
                          size={18}
                          label={store_explorer_settings[key].label}
                          labelStyle={{
                            color: theme === "light" && "#767676",
                            marginLeft: "5px",
                          }}
                          borderColor={
                            dynamicCheckboxes[key]
                              ? theme === "light"
                                ? "#0f0d36"
                                : "#f50057"
                              : theme === "light"
                              ? "#0f0d36"
                              : "rgba(255, 255, 255, 0.7)"
                          }
                          icon={
                            <div
                              style={{
                                height: "100%",
                                width: "100%",
                                backgroundColor:
                                  theme === "light" ? "#0f0d36" : "#f50057",
                                display: "flex",
                                alignItems: "center",
                                justifyContent: "center",
                              }}
                            >
                              <img
                                src={theme === "light" ? tick_white : tick}
                                color={"#fff"}
                                height="80%"
                              ></img>
                            </div>
                          }
                        />
                      )}
                  </div>
                );
              }
            })}
          </div>
          <div style={{ display: "flex", marginLeft: "auto" }}>
            {colorLegend &&
              Object.keys(colorLegend).map((section, index) => (
                <ColorWheel
                  colorLegend={colorLegend}
                  section={section}
                  key={index}
                />
              ))}
          </div>
        </div>
        {tabs && (
          <Tabs
            theme={theme}
            tabs={tabs}
            onTabChange={onTabChange}
            activeTab={activeTab}
          />
        )}
        {/* className ag-theme-alpine for light theme */}
        <div
          className={
            theme === "light" ? " ag-theme-alpine" : "ag-theme-alpine-dark"
          }
          style={{
            height: 400,
            width,
            backgroundColor:
              theme !== "light" ? "rgb(30, 30, 43)" : "rgb(245, 245, 245)",
          }}
        >
          <StyledTable
            rowData={rowData}
            onGridReady={onGridReady}
            getRowHeight={getRowHeight}
            headerHeight="80"
            theme={theme}
          >
            {columns.map((column) => {
              return (
                <AgGridColumn
                  {...column}
                  field={column.field}
                  headerName={column.title}
                  cellRenderer={cellRenderer[column.cellRenderer]}
                />
              );
            })}
          </StyledTable>
        </div>
      </div>
    );
  }
);

export default Table;
