import React from "react";

import ToggleComponent from "commonComponents/Toggle";
import Button from "commonComponents/Button";
import Modal from "commonComponents/Modal";
import Checkbox from "react-custom-checkbox";
import tick from "assets/tick.svg";
import tick_white from "assets/tick_white.svg";
const Toolbar = ({ toolbarConfig, toolbarState, isSaveDisabled, theme }) => (
  <div
    className="shelfToolBar"
    style={{
      display: "flex",
      justifyContent: "space-between",
      color: theme === "light" ? "#000000de" : "#fff",
    }}
  >
    {toolbarConfig.map((config) => {
      if (config.enabled) {
        switch (config.type) {
          case "button":
            return (
              <>
                <Button
                  onClick={config.onClick || config.action}
                  buttonText={config.label[0]}
                  disabled={isSaveDisabled}
                  theme={theme}
                />
                {config.modalData ? (
                  <Modal
                    showModal={toolbarState[config.name]}
                    modalData={config.modalData}
                    toggleModal={config.onClick}
                    onSave={config.action}
                  />
                ) : null}
              </>
            );
            break;
          case "toggle":
            return (
              <label style={{ display: "flex", alignItems: "center" }}>
                {config.label[0]}
                <ToggleComponent
                  handleToggle={config.onClick}
                  isChecked={toolbarState[config.name]}
                  name={`${config.name}-toggle`}
                />
                {config.label[1]}
              </label>
            );
            break;
          case "checkbox":
            return (
              <div style={{ display: "flex" }}>
                <Checkbox
                  checked={toolbarState[config.name]}
                  onChange={config.onClick}
                  borderRadius={2}
                  size={18}
                  borderColor={
                    toolbarState[config.name]
                      ? theme === "light"
                        ? "#0f0d36"
                        : "#f50057"
                      : theme === "light"
                      ? "#0f0d36"
                      : "rgba(255, 255, 255, 0.7)"
                  }
                  label={config.label[0]}
                  icon={
                    <div
                      style={{
                        height: "100%",
                        width: "100%",
                        backgroundColor:
                          theme === "light" ? "#0f0d36" : "#f50057",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                      }}
                    >
                      <img
                        src={theme === "light" ? tick_white : tick}
                        height="80%"
                      ></img>
                    </div>
                  }
                />
              </div>
            );
            break;

          default:
            break;
        }
      }
    })}
  </div>
);

export default Toolbar;
